import java.awt.*;
import java.awt.geom.Point2D;

public class Rocket extends Projectile
{
	private int dist = 2;
	
	public Rocket (Point2D.Double p, int direction)
	{
		super(new Point2D.Double(p.x, p.y), 4, 4, direction);
		
		Sprite sprite = new Sprite(Store.getImage("rocket"));
		
		setSprite(sprite);
	}
	
	public void cycle ()
	{
		if (move(dist))
		{
			if (dist < 24)
			{
				dist++;
			}
			
			if (dist > 5)
			{
				for (Entity entity: GameArea.getLevel().entities)
				{
					if (entity instanceof Damageable)
					{
						if (touching(entity))
						{
							explode();
						}
					}
				}
			}
		}
	}
	
	public boolean move (double dist)
	{
		boolean explode = false;
		
		while (! super.move(dist) && dist > 0)
		{
			explode = true;
			
			dist -= 2;
		}
		
		if (explode)
		{
			explode();
			return false;
		}
		else
		{
			return true;
		}
	}
	
	public boolean move (double dist, int offset)
	{
		return super.move(dist, offset);
	}
	
	public void explode ()
	{
		Store.getAudio("rocket-fire").stop();
		
		GameArea.getLevel().removeEntity(this);
			
		GameArea.getLevel().addEntity(new Explosion(pos));
	}
}
