import java.awt.*;

public class Sprite
{
	private Image[] frames;
	private int currentFrame;
	private long lastChange;
	
	private int time = 100;
	private int limit = 0;
	private boolean running = false;
	
	private int count = 0;
	
	public Sprite (Image image)
	{
		frames = new Image[] { image };
		
		setFrameTime (1000);
	}
	
	public Sprite (Image[] frames)
	{
		this.frames = frames;
	}
	
	public void setFrameTime (int time)
	{
		this.time = time;
	}
	
	public void setLimit (int limit)
	{
		this.limit = limit;
	}
	
	public void start ()
	{
		if (! running)
		{
			count = 0;
			running = true;
			lastChange = System.currentTimeMillis();
		}
	}
	
	public void stop ()
	{
		running = false;
	}
	
	public void nextFrame ()
	{
		currentFrame++;
		
		if (currentFrame == frames.length)
		{
			currentFrame = 0;
			count++;
			
			if (limit > 0 && count >= limit)
			{
				stop();
				
				currentFrame = frames.length - 1;
			}
		}
	}
	
	private void checkTime ()
	{
		while (lastChange + time < System.currentTimeMillis())
		{
			lastChange += time;
			
			nextFrame();
		}
	}
	
	public void draw (Graphics g, int x, int y)
	{
		if (running)
		{
			checkTime();
		}
		
		g.drawImage(frames[currentFrame], x, y, null);
	}
	
	public boolean isRunning ()
	{
		return running;
	}
	
	public Image[] getFrames ()
	{
		return frames;
	}
}
