

abstract class Weapon
{
	protected Entity owner;
	
	public final Sprite sprite;
	public final boolean automaticFire;
	
	Weapon (Entity owner, Sprite sprite)
	{
		this(owner, sprite, false);
	}
	
	Weapon (Entity owner, Sprite sprite, boolean auto)
	{
		this.owner = owner;
		this.sprite = sprite;
		automaticFire = auto;
	}
	
	abstract public void fire ();
}

class Unarmed extends Weapon
{
	Unarmed (Entity owner, Sprite sprite)
	{
		super(owner, sprite);
	}
	
	public void fire () {}
}

class Pistol extends Weapon
{
	private long lastFired;
	private double forwards = 31;
	private double sideways = 26;
	
	Pistol (Entity owner, Sprite sprite)
	{
		super(owner, sprite);
	}
	
	public void fire ()
	{
		long now = System.currentTimeMillis();
		
		if (now - lastFired > 300)
		{
			lastFired = now;
			Bullet bullet = new Bullet(owner.getPosition(), owner.getDirection(), 8);
			
			bullet.move(forwards - owner.outer() + bullet.inner());
			bullet.move(sideways - owner.outer(), -12);
			
			GameArea.getLevel().addEntity(bullet);
			
			Store.getAudio("pistol").play();
		}
	}
}

class MachineGun extends Weapon
{
	private static int i;
	
	private double forwards = 32;
	private double sideways = 22.5;
	
	MachineGun (Entity owner, Sprite sprite)
	{
		super(owner, sprite, true);
	}
	
	public void fire ()
	{
		Store.getAudio("machinegun" + (i++ % 3)).play();
		
		Bullet bullet = new Bullet(owner.getPosition(), owner.getDirection(), 4);
			
		bullet.move(forwards - owner.outer() + bullet.inner());
		bullet.move(sideways - owner.outer(), -12);
		
		GameArea.getLevel().addEntity(bullet);
	}
}

class Bazooka extends Weapon
{
	private long lastFired;
	private double forwards = 32;
	private double sideways = 23;
	
	Bazooka (Entity owner, Sprite sprite)
	{
		super(owner, sprite);
	}
	
	public void fire ()
	{
		long now = System.currentTimeMillis();
		
		if (now - lastFired > 2000)
		{
			Store.getAudio("rocket-fire").play();
			
			lastFired = now;
			Rocket rocket = new Rocket(owner.getPosition(), owner.getDirection());
			
			GameArea.getLevel().addEntity(rocket);
			
			rocket.move(forwards - owner.outer() + rocket.inner());
			rocket.move(sideways - owner.outer(), -12);
		}
		else
		{
			//Store.getAudio("clunk").play();
		}
	}
}
